@@ -10,6 +10,7 @@ from kiara.utils.class_loading import (
     find_data_types_under,
     find_kiara_model_classes_under,
     find_kiara_modules_under,
+    find_kiara_renderers_under,
     find_pipeline_base_path_for_module,
 )
 
@@ -32,3 +33,7 @@ find_pipelines: KiaraEntryPointItem = (
     "kiara_plugin.jupyter.pipelines",
     KIARA_METADATA,
 )
+find_renderer_classes: KiaraEntryPointItem = (
+    find_kiara_renderers_under,
+    "kiara_plugin.jupyter.renderers",
+)
